@@ -16,8 +16,8 @@ use crate::{prelude::*, query::get_public_op_from_db};
 pub async fn authored_ops_to_dht_db(
     network: &(dyn HolochainP2pDnaT + Send + Sync),
     hashes: Vec<(DhtOpHash, AnyDhtHash)>,
-    authored_env: &DbRead<DbKindAuthored>,
-    dht_env: &DbWrite<DbKindDht>,
+    authored_db: &DbRead<DbKindAuthored>,
+    dht_db: &DbWrite<DbKindDht>,
 ) -> StateMutationResult<()> {
     // Check if any agents in this space are an authority for these hashes.
     let mut should_hold_hashes = Vec::new();
@@ -28,19 +28,19 @@ pub async fn authored_ops_to_dht_db(
     }
 
     // Clone the ops into the dht db for the hashes that should be held.
-    authored_ops_to_dht_db_without_check(should_hold_hashes, authored_env, dht_env).await
+    authored_ops_to_dht_db_without_check(should_hold_hashes, authored_db, dht_db).await
 }
 
 /// Insert any authored ops that have been locally validated
 /// into the dht database awaiting integration.
 pub async fn authored_ops_to_dht_db_without_check(
     hashes: Vec<DhtOpHash>,
-    authored_env: &DbRead<DbKindAuthored>,
-    dht_env: &DbWrite<DbKindDht>,
+    authored_db: &DbRead<DbKindAuthored>,
+    dht_db: &DbWrite<DbKindDht>,
 ) -> StateMutationResult<()> {
     // Get the ops from the authored database.
     let mut ops = Vec::with_capacity(hashes.len());
-    let ops = authored_env
+    let ops = authored_db
         .async_reader(move |txn| {
             for hash in hashes {
                 // This function filters out any private entries from ops
@@ -52,7 +52,7 @@ pub async fn authored_ops_to_dht_db_without_check(
             StateMutationResult::Ok(ops)
         })
         .await?;
-    dht_env
+    dht_db
         .async_commit(|txn| {
             for op in ops {
                 insert_locally_validated_op(txn, op)?;
@@ -69,24 +69,20 @@ fn insert_locally_validated_op(txn: &mut Transaction, op: DhtOpHashed) -> StateM
     if is_private_store_entry(op.as_content()) {
         return Ok(());
     }
-    let hash = op.as_hash().clone();
     let op = filter_private_entry(op)?;
+    let hash = op.as_hash();
 
     let dependency = get_dependency(op.get_type(), &op.header());
 
     // Insert the op.
-    insert_op(txn, op)?;
+    insert_op(txn, &op)?;
     // Set the status to valid because we authored it.
-    set_validation_status(
-        txn,
-        hash.clone(),
-        holochain_zome_types::ValidationStatus::Valid,
-    )?;
+    set_validation_status(txn, hash, holochain_zome_types::ValidationStatus::Valid)?;
     // Set the stage to awaiting integration.
     if let Dependency::Null = dependency {
         // This set the validation stage to pending which is correct when
         // it's integrated.
-        set_validation_stage(txn, hash.clone(), ValidationLimboStatus::Pending)?;
+        set_validation_stage(txn, hash, ValidationLimboStatus::Pending)?;
         set_when_integrated(txn, hash, holochain_zome_types::Timestamp::now())?;
     } else {
         set_validation_stage(txn, hash, ValidationLimboStatus::AwaitingIntegration)?;
